@@ -16,7 +16,6 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-#include <stdlib.h>
+//#include <stdlib.h>
 
-// Type Casting
-static GdkGLContext *toGdkGLContext(void *p) { return (GDK_GL_CONTEXT(p)); }
\ No newline at end of file
+static GdkSeat *toGdkSeat(void *p) { return ((GdkSeat *)p); }
\ No newline at end of file
