@@ -1,13 +1,12 @@
-// +build !go1.15
+// +build go1.15
 
 package closure
 
 import "unsafe"
 
 func getAndDeleteClosure(closure unsafe.Pointer) FuncStack {
-	v, ok := closures.Load(closure)
+	v, ok := closures.LoadAndDelete(closure)
 	if ok {
-		closures.Delete(closure)
 		return v.(FuncStack)
 	}
 	return zeroFuncStack
